#!/bin/sh

#############################################################################
#  Licensed Materials - Property of IBM
#  5724-M24
#  Copyright IBM Corporation 2009, 2016. All Rights Reserved.
#  US Government Users Restricted Rights - Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
#############################################################################

echo ""
echo "Start to run Business Space data migration script"
echo ""

#######################################################
#                                                     #
# Subroutine: Usage                                   #
#                                                     #
#######################################################
usage () {
  echo  ""
  echo  "migrateBSpaceData -host <host name> -port <SOAP port>"
  echo  "                  -user <server user id> -password  <server password>"
  echo 	"                  -server <server name> -node  <node name>"
  echo  "                  -cluster <cluster name>"
  echo 	"                  -dbcopy -dbupgrade"
  echo  ""
  echo  "where: " 
  echo  ""
  echo  "-host <host name>:"
  echo  "     The host name of Business Space server you connect to."
  echo  ""
  echo  "-port <SOAP port>:"
  echo  "     The SOAP port of Business Space server you connect to."
  echo  ""
  echo  "-user <user name>:"
  echo  "     The Business Space administrative user."
  echo  ""
  echo  "-password  <user password>:"
  echo  "     The password of the Business Space administrative user."
  echo  "" 
  echo  "-wasHome  <was home>:"
  echo  "     Location of WAS install directory." 
  echo  "" 
  echo  "-server <server name>:"
  echo  "     Name of server, for data migration from V6.2.x in stand-alone environment."
  echo  ""
  echo  "-node  <node name>:"
  echo  "     Name of node, for data migration from V6.2.x in stand-alone environment."
  echo  ""
  echo  "-cluster <cluster name>:"
  echo  "     Name of cluster, for data migration from V6.2.x in network deployment environment."
  echo  ""
  echo  "-dbcopy:"
  echo  "    Copy Business Space data from V7.0.x."
  echo  ""
  echo  "-dbupgrade:"
  echo  "    Upgrade Business Space data from V7.0.x."
  echo  ""  
  exit
}   
  

#######################################################
#                                                     #
# Read command line options                           #
#                                                     #
#######################################################

if [ $# -ne 14 ]; then
  if [ $# -ne 12 ]; then
  	if [ $# -ne 11 ]; then
  		if [ $# -ne 10 ]; then
  			if [ $# -ne 9 ]; then
    			usage
	fi
      fi	
    fi
  fi
fi
  
while [ $# -gt 0 ]; do
  case $1 in
    -host) host=$2; shift; shift;;
    -port) port=$2; shift; shift;;
    -user) user=$2; shift; shift;;
    -password) password=$2; shift; shift;;
    -wasHome) wasHome=$2; shift; shift;;
	-server) server=$2; shift; shift;;
	-node) node=$2; shift; shift;;
	-cluster) cluster=$2; shift; shift;;
	-dbcopy) type="dbcopy"; shift;;
	-dbupgrade) type="dbupgrade"; shift;;
    -h) usage;;
    -help) usage;;
    *) echo "Invalid parameter: $1"; usage;;
  esac;
done

if [ -n "$server" -a -n "$type" ] ; then
  usage
fi

if [ -n "$cluster" -a -n "$type" ] ; then
  usage
fi

if [ -n "$server" -a -n "$cluster" ] ; then
  usage
fi
    
#echo "host=$host"
#echo "port=$port"
#echo "user=$user"
#echo "password=$password"

#######################################################
#                                                     #
# Set WAS environment                                 #
#                                                     #
#######################################################
CUR_DIR=`pwd`
SH_R_DIR=`dirname ${0}`
cd "$SH_R_DIR/../../"
if [ -z "$wasHome" ] ;then
	WASHOME=`pwd`	
else
	WASHOME=$wasHome
fi
#echo "WAS_HOME:$WASHOME"
REPLACE_WAS_HOME=$WASHOME
export WASHOME
. "$WASHOME/bin/setupCmdLine.sh"


#######################################################
#                                                     #
# call migrateBSpaceData.jy                           #
#                                                     #
#######################################################
LOG_DIR=$WAS_HOME/logs/migration
if [ ! -d "$LOG_DIR" ]; then
	mkdir "$LOG_DIR"
fi

if [ -n "$server" ] ; then
"$WASHOME"/bin/wsadmin.sh -connType SOAP -host $host -port $port -user $user -password $password -lang jython -f "$WASHOME"/BusinessSpace/scripts/migrateBSpaceData.jy $server $node
fi

if [ -n "$cluster" ] ; then
"$WASHOME"/bin/wsadmin.sh -connType SOAP -host $host -port $port -user $user -password $password -lang jython -f "$WASHOME"/BusinessSpace/scripts/migrateBSpaceData.jy $cluster
fi

if [ -n "$type" ] ; then
"$WASHOME"/bin/wsadmin.sh -connType SOAP -host $host -port $port -user $user -password $password -lang jython -f "$WASHOME"/BusinessSpace/scripts/migrateBSpaceData.jy $type $user $port
fi
